@@ -1,4 +1,5 @@
 import {
+    __String,
     AccessorDeclaration,
     AllDecorators,
     append,
@@ -51,6 +52,7 @@ import {
     isGeneratedPrivateIdentifier,
     isIdentifier,
     isKeyword,
+    isLocalName,
     isMethodOrAccessor,
     isNamedExports,
     isNamedImports,
@@ -81,7 +83,6 @@ import {
     SuperCall,
     SyntaxKind,
     TransformationContext,
-    UnderscoreEscapedMap,
     VariableDeclaration,
     VariableStatement,
 } from "../_namespaces/ts";
@@ -160,7 +161,7 @@ export function getImportNeedsImportDefaultHelper(node: ImportDeclaration): bool
 /** @internal */
 export function collectExternalModuleInfo(context: TransformationContext, sourceFile: SourceFile, resolver: EmitResolver, compilerOptions: CompilerOptions): ExternalModuleInfo {
     const externalImports: (ImportDeclaration | ImportEqualsDeclaration | ExportDeclaration)[] = [];
-    const exportSpecifiers = createMultiMap<ExportSpecifier>();
+    const exportSpecifiers = createMultiMap<string, ExportSpecifier>();
     const exportedBindings: Identifier[][] = [];
     const uniqueExports = new Map<string, boolean>();
     let exportedNames: Identifier[] | undefined;
@@ -236,7 +237,7 @@ export function collectExternalModuleInfo(context: TransformationContext, source
             case SyntaxKind.VariableStatement:
                 if (hasSyntacticModifier(node, ModifierFlags.Export)) {
                     for (const decl of (node as VariableStatement).declarationList.declarations) {
-                        exportedNames = collectExportedVariableInfo(decl, uniqueExports, exportedNames);
+                        exportedNames = collectExportedVariableInfo(decl, uniqueExports, exportedNames, exportedBindings);
                     }
                 }
                 break;
@@ -314,11 +315,11 @@ export function collectExternalModuleInfo(context: TransformationContext, source
     }
 }
 
-function collectExportedVariableInfo(decl: VariableDeclaration | BindingElement, uniqueExports: Map<string, boolean>, exportedNames: Identifier[] | undefined) {
+function collectExportedVariableInfo(decl: VariableDeclaration | BindingElement, uniqueExports: Map<string, boolean>, exportedNames: Identifier[] | undefined, exportedBindings: Identifier[][]) {
     if (isBindingPattern(decl.name)) {
         for (const element of decl.name.elements) {
             if (!isOmittedExpression(element)) {
-                exportedNames = collectExportedVariableInfo(element, uniqueExports, exportedNames);
+                exportedNames = collectExportedVariableInfo(element, uniqueExports, exportedNames, exportedBindings);
             }
         }
     }
@@ -327,6 +328,9 @@ function collectExportedVariableInfo(decl: VariableDeclaration | BindingElement,
         if (!uniqueExports.get(text)) {
             uniqueExports.set(text, true);
             exportedNames = append(exportedNames, decl.name);
+            if (isLocalName(decl.name)) {
+                multiMapSparseArrayAdd(exportedBindings, getOriginalNodeId(decl), decl.name);
+            }
         }
     }
     return exportedNames;
@@ -652,7 +656,7 @@ export interface PrivateEnvironment<TData, TEntry> {
     /**
      * A mapping of private names to information needed for transformation.
      */
-    identifiers?: UnderscoreEscapedMap<TEntry>;
+    identifiers?: Map<__String, TEntry>;
 
     /**
      * A mapping of generated private names to information needed for transformation.
