@@ -36,6 +36,7 @@ import {
     ImplementationLocation,
     InlayHint,
     InlayHintKind,
+    InteractiveRefactorArguments,
     isString,
     JSDocTagInfo,
     LanguageService,
@@ -52,6 +53,7 @@ import {
     Program,
     QuickInfo,
     RefactorEditInfo,
+    RefactorTriggerReason,
     ReferencedSymbol,
     ReferenceEntry,
     RenameInfo,
@@ -568,15 +570,17 @@ export class SessionClient implements LanguageService {
         return notImplemented();
     }
 
-    findRenameLocations(fileName: string, position: number, findInStrings: boolean, findInComments: boolean, providePrefixAndSuffixTextForRename?: boolean): RenameLocation[] {
+    findRenameLocations(fileName: string, position: number, findInStrings: boolean, findInComments: boolean, preferences: UserPreferences | boolean | undefined): RenameLocation[] {
         if (!this.lastRenameEntry ||
             this.lastRenameEntry.inputs.fileName !== fileName ||
             this.lastRenameEntry.inputs.position !== position ||
             this.lastRenameEntry.inputs.findInStrings !== findInStrings ||
             this.lastRenameEntry.inputs.findInComments !== findInComments) {
-            if (providePrefixAndSuffixTextForRename !== undefined) {
+            const providePrefixAndSuffixTextForRename = typeof preferences === "boolean" ? preferences : preferences?.providePrefixAndSuffixTextForRename;
+            const quotePreference = typeof preferences === "boolean" ? undefined : preferences?.quotePreference;
+            if (providePrefixAndSuffixTextForRename !== undefined || quotePreference !== undefined) {
                 // User preferences have to be set through the `Configure` command
-                this.configure({ providePrefixAndSuffixTextForRename });
+                this.configure({ providePrefixAndSuffixTextForRename, quotePreference });
                 // Options argument is not used, so don't pass in options
                 this.getRenameInfo(fileName, position, /*preferences*/{}, findInStrings, findInComments);
                 // Restore previous user preferences
@@ -682,19 +686,6 @@ export class SessionClient implements LanguageService {
         return { items, applicableSpan, selectedItemIndex, argumentIndex, argumentCount };
     }
 
-    getOccurrencesAtPosition(fileName: string, position: number): ReferenceEntry[] {
-        const args = this.createFileLocationRequestArgs(fileName, position);
-
-        const request = this.processRequest<protocol.OccurrencesRequest>(protocol.CommandTypes.Occurrences, args);
-        const response = this.processResponse<protocol.OccurrencesResponse>(request);
-
-        return response.body!.map(entry => ({ // TODO: GH#18217
-            fileName: entry.file,
-            textSpan: this.decodeSpan(entry),
-            isWriteAccess: entry.isWriteAccess,
-        }));
-    }
-
     getDocumentHighlights(fileName: string, position: number, filesToSearch: string[]): DocumentHighlights[] {
         const args: protocol.DocumentHighlightsRequestArgs = { ...this.createFileLocationRequestArgs(fileName, position), filesToSearch };
 
@@ -739,6 +730,10 @@ export class SessionClient implements LanguageService {
         return notImplemented();
     }
 
+    getLinkedEditingRangeAtPosition(_fileName: string, _position: number): never {
+        return notImplemented();
+    }
+
     getSpanOfEnclosingComment(_fileName: string, _position: number, _onlyMultiLine: boolean): TextSpan {
         return notImplemented();
     }
@@ -794,30 +789,58 @@ export class SessionClient implements LanguageService {
         return { file, line, offset, endLine, endOffset };
     }
 
-    getApplicableRefactors(fileName: string, positionOrRange: number | TextRange): ApplicableRefactorInfo[] {
-        const args = this.createFileLocationOrRangeRequestArgs(positionOrRange, fileName);
-
+    getApplicableRefactors(
+        fileName: string,
+        positionOrRange: number | TextRange,
+        preferences: UserPreferences | undefined,
+        triggerReason?: RefactorTriggerReason,
+        kind?: string,
+        includeInteractiveActions?: boolean): ApplicableRefactorInfo[] {
+        if (preferences) { // Temporarily set preferences
+            this.configure(preferences);
+        }
+        const args: protocol.GetApplicableRefactorsRequestArgs = this.createFileLocationOrRangeRequestArgs(positionOrRange, fileName);
+        args.triggerReason = triggerReason;
+        args.kind = kind;
+        args.includeInteractiveActions = includeInteractiveActions;
         const request = this.processRequest<protocol.GetApplicableRefactorsRequest>(protocol.CommandTypes.GetApplicableRefactors, args);
         const response = this.processResponse<protocol.GetApplicableRefactorsResponse>(request);
+        if (preferences) { // Restore preferences
+            this.configure(this.preferences || {});
+        }
         return response.body!; // TODO: GH#18217
     }
 
+    getMoveToRefactoringFileSuggestions(fileName: string, positionOrRange: number | TextRange): { newFileName: string; files: string[]; } {
+        const args = this.createFileLocationOrRangeRequestArgs(positionOrRange, fileName);
+
+        const request = this.processRequest<protocol.GetMoveToRefactoringFileSuggestionsRequest>(protocol.CommandTypes.GetMoveToRefactoringFileSuggestions, args);
+        const response = this.processResponse<protocol.GetMoveToRefactoringFileSuggestions>(request);
+        return { newFileName: response.body?.newFileName, files:response.body?.files }!;
+    }
+
     getEditsForRefactor(
         fileName: string,
         _formatOptions: FormatCodeSettings,
         positionOrRange: number | TextRange,
         refactorName: string,
-        actionName: string): RefactorEditInfo {
-
-        const args = this.createFileLocationOrRangeRequestArgs(positionOrRange, fileName) as protocol.GetEditsForRefactorRequestArgs;
+        actionName: string,
+        preferences: UserPreferences | undefined,
+        interactiveRefactorArguments?: InteractiveRefactorArguments): RefactorEditInfo {
+        if (preferences) { // Temporarily set preferences
+            this.configure(preferences);
+        }
+        const args =
+            this.createFileLocationOrRangeRequestArgs(positionOrRange, fileName) as protocol.GetEditsForRefactorRequestArgs;
         args.refactor = refactorName;
         args.action = actionName;
+        args.interactiveRefactorArguments = interactiveRefactorArguments;
 
         const request = this.processRequest<protocol.GetEditsForRefactorRequest>(protocol.CommandTypes.GetEditsForRefactor, args);
         const response = this.processResponse<protocol.GetEditsForRefactorResponse>(request);
 
         if (!response.body) {
-            return { edits: [], renameFilename: undefined, renameLocation: undefined };
+            return { edits: [], renameFilename: undefined, renameLocation: undefined, notApplicableReason: undefined };
         }
 
         const edits: FileTextChanges[] = this.convertCodeEditsToTextChanges(response.body.edits);
@@ -825,13 +848,18 @@ export class SessionClient implements LanguageService {
         const renameFilename: string | undefined = response.body.renameFilename;
         let renameLocation: number | undefined;
         if (renameFilename !== undefined) {
-            renameLocation = this.lineOffsetToPosition(renameFilename, response.body.renameLocation!); // TODO: GH#18217
+            renameLocation = this.lineOffsetToPosition(renameFilename, response.body.renameLocation!);
+        }
+
+        if (preferences) { // Restore preferences
+            this.configure(this.preferences || {});
         }
 
         return {
             edits,
             renameFilename,
-            renameLocation
+            renameLocation,
+            notApplicableReason: response.body.notApplicableReason,
         };
     }
 
