@@ -8,8 +8,6 @@ export { Parallel };
 
 export * from "../fourslashRunner";
 export * from "../compilerRunner";
-export * from "../externalCompileRunner";
-export * from "../test262Runner";
 export * from "../runner";
 
 // If running as emitted CJS, don't start executing the tests here; instead start in runner.ts.
