@@ -18,7 +18,6 @@ import * as vpath from "./_namespaces/vpath";
 export const enum CompilerTestType {
     Conformance,
     Regressions,
-    Test262
 }
 
 interface CompilerFileBasedTest extends FileBasedTest {
@@ -41,9 +40,6 @@ export class CompilerBaselineRunner extends RunnerBase {
         else if (testType === CompilerTestType.Regressions) {
             this.testSuiteName = "compiler";
         }
-        else if (testType === CompilerTestType.Test262) {
-            this.testSuiteName = "test262";
-        }
         else {
             this.testSuiteName = "compiler"; // default to this for historical reasons
         }
