@@ -1,16 +1,7 @@
 import * as Harness from "../../_namespaces/Harness";
 import * as ts from "../../_namespaces/ts";
-import {
-    commandLineCallbacks,
-    compilerOptionsToConfigJson,
-} from "../tsc/helpers";
-import {
-    createWatchedSystem,
-    File,
-    libFile,
-    SymLink,
-    TestServerHost,
-} from "../virtualFileSystemWithWatch";
+import { commandLineCallbacks } from "../helpers/baseline";
+import { compilerOptionsToConfigJson } from "../helpers/contents";
 import {
     commonFile1,
     commonFile2,
@@ -21,7 +12,14 @@ import {
     TscWatchCompileChange,
     verifyTscWatch,
     watchBaseline,
-} from "./helpers";
+} from "../helpers/tscWatch";
+import {
+    createWatchedSystem,
+    File,
+    libFile,
+    SymLink,
+    TestServerHost,
+} from "../helpers/virtualFileSystemWithWatch";
 
 describe("unittests:: tsc-watch:: program updates", () => {
     const scenario = "programUpdates";
@@ -110,7 +108,7 @@ describe("unittests:: tsc-watch:: program updates", () => {
             {
                 caption: "Create commonFile2",
                 edit: sys => sys.writeFile(commonFile2.path, commonFile2.content),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -145,17 +143,17 @@ describe("unittests:: tsc-watch:: program updates", () => {
             {
                 caption: "change file to ensure signatures are updated",
                 edit: sys => sys.appendFile(commonFile2.path, ";let xy = 10;"),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "delete file2",
                 edit: sys => sys.deleteFile(commonFile2.path),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "recreate file2",
                 edit: sys => sys.writeFile(commonFile2.path, commonFile2.content),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -176,7 +174,7 @@ describe("unittests:: tsc-watch:: program updates", () => {
             {
                 caption: "create file2",
                 edit: sys => sys.writeFile(commonFile2.path, commonFile2.content),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -199,7 +197,7 @@ describe("unittests:: tsc-watch:: program updates", () => {
             {
                 caption: "change file to ensure signatures are updated",
                 edit: sys => sys.appendFile(commonFile2.path, ";let xy = 10;"),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "Change config",
@@ -207,7 +205,7 @@ describe("unittests:: tsc-watch:: program updates", () => {
                         "compilerOptions": {},
                         "files": ["${commonFile1.path}"]
                     }`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -233,7 +231,7 @@ describe("unittests:: tsc-watch:: program updates", () => {
                         "compilerOptions": {},
                         "files": ["${commonFile1.path}", "${commonFile2.path}"]
                     }`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -261,14 +259,14 @@ describe("unittests:: tsc-watch:: program updates", () => {
                 edit: sys => sys.modifyFile("/tsconfig.json", JSON.stringify({
                     compilerOptions: { allowUnusedLabels: false }
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1)
+                timeouts: sys => sys.runQueuedTimeoutCallbacks()
             },
             {
                 caption: "Enable  allowUnsusedLabels",
                 edit: sys => sys.modifyFile("/tsconfig.json", JSON.stringify({
                     compilerOptions: { allowUnusedLabels: true }
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -302,7 +300,7 @@ describe("unittests:: tsc-watch:: program updates", () => {
                     compilerOptions: { allowArbitraryExtensions: false },
                     files: ["/a.ts"],
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1)
+                timeouts: sys => sys.runQueuedTimeoutCallbacks()
             },
             {
                 caption: "Enable  allowArbitraryExtensions",
@@ -310,7 +308,7 @@ describe("unittests:: tsc-watch:: program updates", () => {
                     compilerOptions: { allowArbitraryExtensions: true },
                     files: ["/a.ts"],
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -346,7 +344,7 @@ export class A {
                 edit: sys => sys.modifyFile("/tsconfig.json", JSON.stringify({
                     compilerOptions: { target: "es6", importsNotUsedAsValues: "error", experimentalDecorators: true }
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
 
             },
             {
@@ -354,7 +352,7 @@ export class A {
                 edit: sys => sys.modifyFile("/tsconfig.json", JSON.stringify({
                     compilerOptions: { target: "es6", importsNotUsedAsValues: "error", experimentalDecorators: true, emitDecoratorMetadata: true }
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -416,7 +414,7 @@ export class A {
                         },
                         "files": ["/a/b/file1.ts"]
                     }`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -464,7 +462,7 @@ export class A {
                 caption: "Modify f2 to include f3",
                 // now inferred project should inclule file3
                 edit: sys => sys.modifyFile("/a/b/f2.ts", `export * from "../c/f3"`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -492,7 +490,7 @@ export class A {
             {
                 caption: "Delete f2",
                 edit: sys => sys.deleteFile("/a/b/f2.ts"),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -520,7 +518,7 @@ export class A {
             {
                 caption: "Delete f2",
                 edit: sys => sys.deleteFile("/a/b/f2.ts"),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -563,7 +561,7 @@ export class A {
         },
         edits: [{
             caption: "change `module` to 'none'",
-            timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+            timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             edit: sys => {
                 sys.writeFile(configFilePath, JSON.stringify({ compilerOptions: { module: "none" } }));
             }
@@ -621,7 +619,7 @@ export class A {
             oldSnap: oldSnap2,
         });
 
-        sys.checkTimeoutQueueLength(0);
+        sys.logTimeoutQueueLength();
         baseline.push(`First program is not updated:: ${getPrograms() === ts.emptyArray}`);
         baseline.push(`Second program is not updated:: ${getPrograms2() === ts.emptyArray}`);
         Harness.Baseline.runBaseline(`tscWatch/${scenario}/two-watch-programs-are-not-affected-by-each-other.js`, baseline.join("\r\n"));
@@ -642,7 +640,7 @@ export class A {
             {
                 caption: "Write f2",
                 edit: sys => sys.writeFile("/a/b/f2.ts", "let y = 1"),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -670,7 +668,7 @@ export class A {
             {
                 caption: "Modify config to make f2 as root too",
                 edit: sys => sys.writeFile(configFilePath, JSON.stringify({ compilerOptions: {}, files: ["f1.ts", "f2.ts"] })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -698,12 +696,12 @@ export class A {
             {
                 caption: "Add new file",
                 edit: sys => sys.writeFile(`/user/username/projects/myproject/new-file.ts`, "export const z = 1;"),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "Import new file",
                 edit: sys => sys.prependFile(`/user/username/projects/myproject/f1.ts`, `import { z } from "./new-file";`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -727,7 +725,7 @@ export class A {
             {
                 caption: "Write file2",
                 edit: sys => sys.writeFile(`/user/username/projects/myproject/Project/file2.ts`, "export const y = 10;"),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1)
+                timeouts: sys => sys.runQueuedTimeoutCallbacks()
             }
         ]
     });
@@ -755,7 +753,7 @@ export class A {
             {
                 caption: "Modify config to set outFile option",
                 edit: sys => sys.writeFile(configFilePath, JSON.stringify({ compilerOptions: { outFile: "out.js" }, files: ["f1.ts", "f2.ts"] })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -783,7 +781,7 @@ export class A {
             {
                 caption: "Delete f2",
                 edit: sys => sys.deleteFile("/a/b/f2.ts"),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -807,7 +805,7 @@ export class A {
             {
                 caption: "Delete config file",
                 edit: sys => sys.deleteFile(configFilePath),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -881,7 +879,7 @@ declare const eval: any`
                         }
                     })
                 ),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             }
         ]
     });
@@ -917,28 +915,28 @@ declare const eval: any`
     const changeModuleFileToModuleFile1: TscWatchCompileChange = {
         caption: "Rename moduleFile to moduleFile1",
         edit: sys => {
-            sys.renameFile("/a/b/moduleFile.ts", "/a/b/moduleFile1.ts");
-            sys.deleteFile("/a/b/moduleFile.js");
+            sys.renameFile("/users/username/projects/project/moduleFile.ts", "/users/username/projects/project/moduleFile1.ts");
+            sys.deleteFile("/users/username/projects/project/moduleFile.js");
         },
         timeouts: runQueuedTimeoutCallbacksTwice
     };
     const changeModuleFile1ToModuleFile: TscWatchCompileChange = {
         caption: "Rename moduleFile1 back to moduleFile",
-        edit: sys => sys.renameFile("/a/b/moduleFile1.ts", "/a/b/moduleFile.ts"),
+        edit: sys => sys.renameFile("/users/username/projects/project/moduleFile1.ts", "/users/username/projects/project/moduleFile.ts"),
         timeouts: runQueuedTimeoutCallbacksTwice,
     };
 
     verifyTscWatch({
         scenario,
         subScenario: "rename a module file and rename back should restore the states for inferred projects",
-        commandLineArgs: ["-w", "/a/b/file1.ts"],
+        commandLineArgs: ["-w", "/users/username/projects/project/file1.ts"],
         sys: () => {
             const moduleFile = {
-                path: "/a/b/moduleFile.ts",
+                path: "/users/username/projects/project/moduleFile.ts",
                 content: "export function bar() { };"
             };
             const file1 = {
-                path: "/a/b/file1.ts",
+                path: "/users/username/projects/project/file1.ts",
                 content: 'import * as T from "./moduleFile"; T.bar();'
             };
             return createWatchedSystem([moduleFile, file1, libFile]);
@@ -952,16 +950,20 @@ declare const eval: any`
     verifyTscWatch({
         scenario,
         subScenario: "rename a module file and rename back should restore the states for configured projects",
-        commandLineArgs: ["-w", "-p", configFilePath],
+        commandLineArgs: ["-w", "-p", "/users/username/projects/project/tsconfig.json"],
         sys: () => {
             const moduleFile = {
-                path: "/a/b/moduleFile.ts",
+                path: "/users/username/projects/project/moduleFile.ts",
                 content: "export function bar() { };"
             };
             const file1 = {
-                path: "/a/b/file1.ts",
+                path: "/users/username/projects/project/file1.ts",
                 content: 'import * as T from "./moduleFile"; T.bar();'
             };
+            const configFile = {
+                path: "/users/username/projects/project/tsconfig.json",
+                content: `{}`
+            };
             return createWatchedSystem([moduleFile, file1, configFile, libFile]);
         },
         edits: [
@@ -970,37 +972,45 @@ declare const eval: any`
         ]
     });
 
-    verifyTscWatch({
-        scenario,
-        subScenario: "types should load from config file path if config exists",
-        commandLineArgs: ["-w", "-p", configFilePath],
-        sys: () => {
-            const f1 = {
-                path: "/a/b/app.ts",
-                content: "let x = 1"
-            };
-            const config = {
-                path: configFilePath,
-                content: JSON.stringify({ compilerOptions: { types: ["node"], typeRoots: [] } })
-            };
-            const node = {
-                path: "/a/b/node_modules/@types/node/index.d.ts",
-                content: "declare var process: any"
-            };
-            const cwd = {
-                path: "/a/c"
-            };
-            return createWatchedSystem([f1, config, node, cwd, libFile], { currentDirectory: cwd.path });
-        },
+    describe("types from config file", () => {
+        function verifyTypesLoad(includeTypeRoots: boolean) {
+            verifyTscWatch({
+                scenario,
+                subScenario: includeTypeRoots ?
+                    "types should not load from config file path if config exists but does not specifies typeRoots" :
+                    "types should load from config file path if config exists",
+                commandLineArgs: ["-w", "-p", configFilePath],
+                sys: () => {
+                    const f1 = {
+                        path: "/a/b/app.ts",
+                        content: "let x = 1"
+                    };
+                    const config = {
+                        path: configFilePath,
+                        content: JSON.stringify({ compilerOptions: { types: ["node"], typeRoots: includeTypeRoots ? [] : undefined } })
+                    };
+                    const node = {
+                        path: "/a/b/node_modules/@types/node/index.d.ts",
+                        content: "declare var process: any"
+                    };
+                    const cwd = {
+                        path: "/a/c"
+                    };
+                    return createWatchedSystem([f1, config, node, cwd, libFile], { currentDirectory: cwd.path });
+                },
+            });
+        }
+        verifyTypesLoad(/*includeTypeRoots*/ false);
+        verifyTypesLoad(/*includeTypeRoots*/ true);
     });
 
     verifyTscWatch({
         scenario,
         subScenario: "add the missing module file for inferred project-should remove the module not found error",
-        commandLineArgs: ["-w", "/a/b/file1.ts"],
+        commandLineArgs: ["-w", "/users/username/projects/project/file1.ts"],
         sys: () => {
             const file1 = {
-                path: "/a/b/file1.ts",
+                path: "/users/username/projects/project/file1.ts",
                 content: 'import * as T from "./moduleFile"; T.bar();'
             };
             return createWatchedSystem([file1, libFile]);
@@ -1008,7 +1018,7 @@ declare const eval: any`
         edits: [
             {
                 caption: "Create module file",
-                edit: sys => sys.writeFile("/a/b/moduleFile.ts", "export function bar() { }"),
+                edit: sys => sys.writeFile("/users/username/projects/project/moduleFile.ts", "export function bar() { }"),
                 timeouts: runQueuedTimeoutCallbacksTwice,
             }
         ]
@@ -1226,7 +1236,7 @@ declare const eval: any`
                     {
                         caption: "Add new file",
                         edit: sys => sys.writeFile(`/user/username/projects/myproject/src/file3.ts`, `export const y = 10;`),
-                        timeouts: sys => sys.checkTimeoutQueueLengthAndRun(2), // To update program and failed lookups
+                        timeouts: sys => sys.runQueuedTimeoutCallbacks(), // To update program and failed lookups
                     },
                     noopChange,
                 ]
@@ -1835,7 +1845,7 @@ import { x } from "../b";`),
                     compilerOptions: {},
                     files: [commonFile1.path, commonFile2.path]
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "Change first extended config",
@@ -1844,7 +1854,7 @@ import { x } from "../b";`),
                         strict: false,
                     }
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "Change second extended config",
@@ -1854,7 +1864,7 @@ import { x } from "../b";`),
                         strictNullChecks: true,
                     }
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "Change config to stop extending another config",
@@ -1862,7 +1872,7 @@ import { x } from "../b";`),
                     compilerOptions: {},
                     files: [commonFile1.path, commonFile2.path]
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
         ]
     });
@@ -1900,7 +1910,7 @@ import { x } from "../b";`),
             {
                 caption: "Add module3 to folder2",
                 edit: sys => sys.writeFile(`/user/username/projects/myproject/client/linktofolder2/module3.ts`, `import * as M from "folder1/module1";`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
         ]
     });
@@ -1951,27 +1961,27 @@ import { x } from "../b";`),
             {
                 caption: "Add class3 to project1",
                 edit: sys => sys.writeFile(`/user/username/projects/myproject/projects/project1/class3.ts`, `class class3 {}`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "Add output of class3",
                 edit: sys => sys.writeFile(`/user/username/projects/myproject/projects/project1/class3.d.ts`, `declare class class3 {}`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "Add excluded file to project1",
                 edit: sys => sys.ensureFileOrFolder({ path: `/user/username/projects/myproject/projects/project1/temp/file.d.ts`, content: `declare class file {}` }),
-                timeouts: sys => sys.checkTimeoutQueueLength(0),
+                timeouts: sys => sys.logTimeoutQueueLength(),
             },
             {
                 caption: "Delete output of class3",
                 edit: sys => sys.deleteFile(`/user/username/projects/myproject/projects/project1/class3.d.ts`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
             {
                 caption: "Add output of class3",
                 edit: sys => sys.writeFile(`/user/username/projects/myproject/projects/project1/class3.d.ts`, `declare class class3 {}`),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
         ]
     });
@@ -1995,7 +2005,7 @@ import { x } from "../b";`),
             {
                 caption: "Create foo in project root",
                 edit: sys => sys.writeFile(`/user/username/projects/myproject/foo`, ``),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
         ]
     });
@@ -2033,7 +2043,7 @@ import { x } from "../b";`),
                         allowImportingTsExtensions: true
                     }
                 })),
-                timeouts: sys => sys.checkTimeoutQueueLengthAndRun(1),
+                timeouts: sys => sys.runQueuedTimeoutCallbacks(),
             },
         ]
     });
