@@ -198,10 +198,36 @@ branch({
   }
 })
 
+interface Props<T> {
+  a: (x: string) => T;
+  b: (arg: T) => void;
+}
+
+declare function Foo<T>(props: Props<T>): null;
+
+Foo({
+  ...{
+    a: (x) => 10,
+    b: (arg) => {
+      arg.toString();
+    },
+  },
+});
 
 //// [intraExpressionInferences.js]
 "use strict";
 // Repros from #47599
+var __assign = (this && this.__assign) || function () {
+    __assign = Object.assign || function(t) {
+        for (var s, i = 1, n = arguments.length; i < n; i++) {
+            s = arguments[i];
+            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
+                t[p] = s[p];
+        }
+        return t;
+    };
+    return __assign.apply(this, arguments);
+};
 callIt({
     produce: function () { return 0; },
     consume: function (n) { return n.toFixed(); }
@@ -316,6 +342,12 @@ branch({
         var test1 = u;
     }
 });
+Foo(__assign({
+    a: function (x) { return 10; },
+    b: function (arg) {
+        arg.toString();
+    },
+}));
 
 
 //// [intraExpressionInferences.d.ts]
@@ -383,3 +415,8 @@ declare const branch: <T, U extends T>(_: {
     then: (u: U) => void;
 }) => void;
 declare const x: "a" | "b";
+interface Props<T> {
+    a: (x: string) => T;
+    b: (arg: T) => void;
+}
+declare function Foo<T>(props: Props<T>): null;
