@@ -18,7 +18,7 @@ export const brandColors = {
 
 //// [index.d.ts]
 export namespace colors {
-    const royalBlue: string;
+    let royalBlue: string;
 }
 export namespace brandColors {
     import purple = colors.royalBlue;
