@@ -1,3 +1,4 @@
+currentDirectory:: /user/username/projects/solution useCaseSensitiveFileNames: false
 Input::
 //// [/a/lib/lib.d.ts]
 /// <reference no-default-lib="true"/>
@@ -57,18 +58,16 @@ Shape signatures in builder refreshed for::
 /user/username/projects/solution/app/filewitherror.ts (used version)
 /user/username/projects/solution/app/filewithouterror.ts (computed .d.ts during emit)
 
-PolledWatches::
-
 FsWatches::
-/user/username/projects/solution/app/tsconfig.json:
+/user/username/projects/solution/app/tsconfig.json: *new*
   {}
-/user/username/projects/solution/app/filewitherror.ts:
+/user/username/projects/solution/app/filewitherror.ts: *new*
   {}
-/user/username/projects/solution/app/filewithouterror.ts:
+/user/username/projects/solution/app/filewithouterror.ts: *new*
   {}
 
 FsWatchesRecursive::
-/user/username/projects/solution/app:
+/user/username/projects/solution/app: *new*
   {}
 
 exitCode:: ExitStatus.undefined
@@ -81,6 +80,9 @@ Input::
 export class myClass2 { }
 
 
+Before running Timeout callback:: count: 1
+1: timerToBuildInvalidatedProject
+After running Timeout callback:: count: 0
 Output::
 >> Screen clear
 [[90m12:00:30 AM[0m] File change detected. Starting incremental compilation...
@@ -108,19 +110,5 @@ Semantic diagnostics in builder refreshed for::
 Shape signatures in builder refreshed for::
 /user/username/projects/solution/app/filewithouterror.ts (computed .d.ts)
 
-PolledWatches::
-
-FsWatches::
-/user/username/projects/solution/app/tsconfig.json:
-  {}
-/user/username/projects/solution/app/filewitherror.ts:
-  {}
-/user/username/projects/solution/app/filewithouterror.ts:
-  {}
-
-FsWatchesRecursive::
-/user/username/projects/solution/app:
-  {}
-
 exitCode:: ExitStatus.undefined
 
