@@ -1,3 +1,4 @@
+currentDirectory:: /a/b useCaseSensitiveFileNames: false
 Input::
 //// [/a/lib/lib.d.ts]
 /// <reference no-default-lib="true"/>
@@ -92,28 +93,24 @@ Shape signatures in builder refreshed for::
 /a/lib/lib.d.ts (used version)
 /a/b/other.ts (computed .d.ts during emit)
 
-PolledWatches::
-
 FsWatches::
-/a/b/project1.tsconfig.json:
+/a/b/project1.tsconfig.json: *new*
   {}
-/a/b/alpha.tsconfig.json:
+/a/b/alpha.tsconfig.json: *new*
   {}
-/a/b/commonfile1.ts:
+/a/b/commonfile1.ts: *new*
   {}
-/a/b/commonfile2.ts:
+/a/b/commonfile2.ts: *new*
   {}
-/a/b/project2.tsconfig.json:
+/a/b/project2.tsconfig.json: *new*
   {}
-/a/b/bravo.tsconfig.json:
+/a/b/bravo.tsconfig.json: *new*
   {}
-/a/b/other.ts:
+/a/b/other.ts: *new*
   {}
-/a/b/tsconfig.json:
+/a/b/tsconfig.json: *new*
   {}
 
-FsWatchesRecursive::
-
 exitCode:: ExitStatus.undefined
 
 //// [/a/b/commonFile1.js]
@@ -273,6 +270,9 @@ Input::
 {"references":[{"path":"./project1.tsconfig.json"}],"files":[]}
 
 
+Before running Timeout callback:: count: 1
+1: timerToBuildInvalidatedProject
+After running Timeout callback:: count: 0
 Output::
 >> Screen clear
 [[90m12:00:58 AM[0m] File change detected. Starting incremental compilation...
@@ -281,8 +281,6 @@ Output::
 
 
 
-PolledWatches::
-
 FsWatches::
 /a/b/project1.tsconfig.json:
   {}
@@ -295,7 +293,13 @@ FsWatches::
 /a/b/tsconfig.json:
   {}
 
-FsWatchesRecursive::
+FsWatches *deleted*::
+/a/b/project2.tsconfig.json:
+  {}
+/a/b/bravo.tsconfig.json:
+  {}
+/a/b/other.ts:
+  {}
 
 exitCode:: ExitStatus.undefined
 
