@@ -9,4 +9,12 @@ function foo1() {
 function foo2() {
     return E.A
     const enum E { A }
-}
\ No newline at end of file
+}
+
+const config = {
+    a: AfterObject.A,
+};
+
+const enum AfterObject {
+    A = 2,
+}
