@@ -26,4 +26,8 @@ g2.give(1);
 
 const g3 = g(GenericNumberOrString);
 g3.give(1);
-g3.give('1');
\ No newline at end of file
+g3.give('1');
+
+// repro from #35636
+class C<T> {}
+const g4 = g(C);
