@@ -6,9 +6,4 @@
 ////    }
 ////}
 
-goTo.marker("1");
-verify.occurrencesAtPositionCount(1);
-goTo.marker("2");
-verify.occurrencesAtPositionCount(1);
-goTo.marker("3");
-verify.occurrencesAtPositionCount(1);
\ No newline at end of file
+verify.baselineDocumentHighlights(["1", "2", "3"]);
\ No newline at end of file
