@@ -9,4 +9,4 @@
 ////	static [|/*1*/override|] m() {}
 ////}
 
-verify.goToDefinition("1", "2");
+verify.baselineGoToDefinition("1");
